"use strict";
// Copyright (c) Uber Technologies, Inc.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("@jupyter-widgets/base");
const version_1 = require("./version");
const utils_1 = require("./utils");
const mapboxgl = require('mapbox-gl');
const deckgl = require('@deck.gl/core');
const deckglLayers = require('@deck.gl/layers');
const deckAggregationLayers = require('@deck.gl/aggregation-layers');
const deckJson = require('@deck.gl/json');
const MAPBOX_CSS_URL = 'https://api.tiles.mapbox.com/mapbox-gl-js/v0.47.0/mapbox-gl.css';
const MAPBOX_TILE_URL = 'mapbox://styles/mapbox/light-v9';
class DeckGLModel extends base_1.DOMWidgetModel {
    defaults() {
        return Object.assign({}, super.defaults(), { _model_name: DeckGLModel.model_name, _model_module: DeckGLModel.model_module, _model_module_version: DeckGLModel.model_module_version, _view_name: DeckGLModel.view_name, _view_module: DeckGLModel.view_module, _view_module_version: DeckGLModel.view_module_version, json_input: null });
    }
}
DeckGLModel.serializers = Object.assign({}, base_1.DOMWidgetModel.serializers);
DeckGLModel.model_name = 'DeckGLModel';
DeckGLModel.model_module = version_1.MODULE_NAME;
DeckGLModel.model_module_version = version_1.MODULE_VERSION;
DeckGLModel.view_name = 'DeckGLView'; // Set to null if no view
DeckGLModel.view_module = version_1.MODULE_NAME; // Set to null if no view
DeckGLModel.view_module_version = version_1.MODULE_VERSION;
exports.DeckGLModel = DeckGLModel;
class DeckGLView extends base_1.DOMWidgetView {
    render() {
        super.render();
        this.listenTo(this.model, 'change:json_input', this.value_changed);
        utils_1.loadCss(MAPBOX_CSS_URL);
        utils_1.createDeckScaffold(this.el);
    }
    _onViewStateChange({ viewState }) {
        this.deck.setProps({ viewState });
        utils_1.setMapProps(this.mapLayer, { viewState });
    }
    initJSElements() {
        if (!this.deck) {
            mapboxgl.accessToken = this.model.get('mapbox_key');
            this.deck = new deckgl.Deck({
                canvas: 'deck-map-container',
                height: '100%',
                width: '100%',
                mapboxApiAccessToken: mapboxgl.accessToken,
                views: [new deckgl.MapView()],
                onViewStateChange: this._onViewStateChange.bind(this)
            });
        }
        if (!this.mapLayer) {
            this.mapLayer = new mapboxgl.Map({
                container: 'map',
                interactive: false,
                style: MAPBOX_TILE_URL
            });
        }
    }
    value_changed() {
        this.json_input = this.model.get('json_input');
        this.initJSElements();
        let jsonConverter = new deckJson._JSONConverter({
            'configuration': {
                'layers': {
                    'GeoJsonLayer': deckglLayers.GeoJsonLayer,
                    'HexagonLayer': deckAggregationLayers.HexagonLayer,
                    'ScatterplotLayer': deckglLayers.ScatterplotLayer,
                    'TextLayer': deckglLayers.TextLayer,
                    'LineLayer': deckglLayers.LineLayer
                }
            }
        });
        const results = jsonConverter.convertJsonToDeckProps(JSON.parse(this.json_input));
        this.deck.setProps(results);
        utils_1.hideMapboxCSSWarning();
        utils_1.setMapProps(this.mapLayer, this.deck.props);
    }
}
exports.DeckGLView = DeckGLView;
//# sourceMappingURL=widget.js.map